{
	"name" : "Scrum, Agile Development Method",
	"version": "1.0",
	"author" : "Tiny",
	"depends" : ["project"],
	"category" : "Enterprise Specific Modules/Information Technology",
	"init_xml" : [],
	"demo_xml" : ["scrum_demo.xml"],
	"update_xml": ["scrum_view.xml","scrum_report.xml", "scrum_wizard.xml"],
	"active": True
}
